# inspec-ai

This library contains all the prototypes that were developped by the Moov AI product team.   

## Installation

To add inSpec to your project, you can run the following command:

```
pip install inspec-ai
```

NOTE: inspec-ai was developped using Python 3.9.

## Documentation

For more information on each specific function, please consult their specific documentation page in the `docs/` folder on the repository.
## License

Copyright (c) 2022 MoovAI Technologies Inc.

Permission is hereby granted, free of charge, to any person or organization 
obtaining a copy of this software and associated documentation files 
(the "Software"), to use and copy the Software within the internal operations of 
aforementioned person or organization, excluding any use of the Software that 
benefits a third party, including, among others, in the context of providing 
services to such third party or in publishing, distributing, sublicensing or 
selling copies of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.